//Simulate the baseline RBC model against an aggregate TFP shock
//Use Dynare built-in solver to solve the steady state
//IRF plots absolute deviation from the steady state level
var y c i k n w r a;
varexo e;
parameters alph betta phi gam delt rho sigma nk_ss ck_ss n_ss;
alph = 0.30;
betta = 0.96;
delt = 0.10;
gam = 2.00;
rho = 0.90;
sigma = 0.01;
nk_ss = ((1/betta-1+delt)/alph)^(1/(1-alph));
ck_ss = nk_ss^(1-alph)-delt;
n_ss = 1/3;
phi = (1-alph)*nk_ss^(1-alph)/(n_ss^(1+gam)*ck_ss);

model;
y = exp(a)*k(-1)^alph*n^(1-alph);
a = rho*a(-1)+e;
k = (1-delt)*k(-1) + i;
alph*y/k(-1)=r;
(1-alph)*y/n = w;
phi*n^gam = w/c;
1/c = betta*1/c(+1)*(r(+1)+1-delt);
y = c + i;
end;

initval;
a = 0;
n = n_ss;
k = n/(nk_ss);
c = k*ck_ss;
y = exp(a)*k^alph*n^(1-alph);
i = delt*k;
r = alph*nk_ss^(1-alph);
w = (1-alph)*nk_ss^(-alph);
end;

steady;

shocks;
var e = sigma^2;
end;

stoch_simul(order = 1,irf=40) y c i k n w r a;
