//Simulate the baseline RBC model against an aggregate TFP shock
//Provide Dynare with steady-state values by "steady_state_model"
//IRF plots percentage deviation from the steady state, by defining log-level endo variables & setting variance of exo vr = (0.01)^2.
var y logy c logc i logi k logk n logn w logw r logr a  ;
varexo e;
parameters alph betta phi gam delt rho sigma;
alph = 0.30;
betta = 0.96;
delt = 0.10;
gam = 2.00;
rho = 0.90;
sigma = 0.01;
//We can delay the specification of phi to the "steady_state_model" module

model;
y = exp(a)*k(-1)^alph*n^(1-alph);
a = rho*a(-1)+e;
k = (1-delt)*k(-1) + i;
alph*y/k(-1)=r;
(1-alph)*y/n = w;
phi*n^gam = w/c;
1/c = betta*1/c(+1)*(r(+1)+1-delt);
y = c + i;
logy = 100*log(y);
logc = 100*log(c);
logi = 100*log(i);
logk = 100*log(k);
logn = 100*log(n);
logw = 100*log(w);
logr = 100*log(r);
end;

steady_state_model;
a = 0;
nk_ss = ((1/betta-1+delt)/alph)^(1/(1-alph));
ck_ss = nk_ss^(1-alph)-delt;
n = 1/3;
phi = (1-alph)*nk_ss^(1-alph)/(n^(1+gam)*ck_ss);
k = n/(nk_ss);
c = k*ck_ss;
y = exp(a)*k^alph*n^(1-alph);
i = delt*k;
r = alph*nk_ss^(1-alph);
w = (1-alph)*nk_ss^(-alph);
logy = 100*log(y);
logc = 100*log(c);
logi = 100*log(i);
logk = 100*log(k);
logn = 100*log(n);
logw = 100*log(w);
logr = 100*log(r);
end;

shocks;
var e = sigma^2;
end;

stoch_simul(order = 1,irf=40) logy logc logi logk logn logw logr a;
