function [ys,params,check] = BaselineRBC3_steadystate(ys,exo,M_,options_)
% function [ys,params,check] = NK_baseline_steadystate(ys,exo,M_,options_)
% computes the steady state for the NK_baseline.mod and uses a numerical
% solver to do so
% Inputs: 
%   - ys        [vector] vector of initial values for the steady state of
%                   the endogenous variables
%   - exo       [vector] vector of values for the exogenous variables
%   - M_        [structure] Dynare model structure
%   - options   [structure] Dynare options structure
%
% Output: 
%   - ys        [vector] vector of steady state values for the the endogenous variables
%   - params    [vector] vector of parameter values
%   - check     [scalar] set to 0 if steady state computation worked and to
%                    1 of not (allows to impose restrictions on parameters)

%% Step 1: read out parameters to access them with their name
NumberOfParameters = M_.param_nbr;
for ii = 1:NumberOfParameters
  paramname = M_.param_names{ii};
  eval([ paramname ' = M_.params(' int2str(ii) ');']);
end
% initialize indicator
check = 0;

%% Step 2: Steady-state value calculation & Parameter calibration (in this baseline RBC model, we only need to calculate steady-state value)
a = 0;
nk_ss = ((1/betta-1+delt)/alph)^(1/(1-alph));
ck_ss = nk_ss^(1-alph)-delt;
n = 1/3;
phi = (1-alph)*nk_ss^(1-alph)/(n^(1+gam)*ck_ss);
k = n/(nk_ss);
k_m = k;
c = k*ck_ss;
y = exp(a)*k^alph*n^(1-alph);
i = delt*k;
r = alph*nk_ss^(1-alph);
w = (1-alph)*nk_ss^(-alph);
logy = 100*log(y);
logc = 100*log(c);
logi = 100*log(i);
logk = 100*log(k);
logn = 100*log(n);
logw = 100*log(w);
logr = 100*log(r);
logk_m = 100*log(k_m);
%% Step 3: Update parameters and variables
params=NaN(NumberOfParameters,1);
for iter = 1:length(M_.params) %update parameters set in the file
  eval([ 'params(' num2str(iter) ') = ' M_.param_names{iter} ';' ])
end

NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
for ii = 1:NumberOfEndogenousVariables
  varname = M_.endo_names{ii};
  eval(['ys(' int2str(ii) ') = ' varname ';']);
end
end