//Simulate the baseline RBC model against an aggregate TFP shock and demand shock
//Use a separate .m file to solve the steady state
var y logy c logc i logi k logk k_m logk_m n logn w logw r logr a logbetta;
varexo e_a e_betta;

parameters alph logbetta_ss phi gam delt rho_a rho_betta sigma_a sigma_betta;
alph = 0.30;
logbetta_ss = log(0.96);
delt = 0.10;
gam = 2.00;
rho_a = 0.90;
rho_betta = 0.90;
sigma_a = 0.01;
sigma_betta = 0.01;

model;
logbetta = (1-rho_betta)*logbetta_ss+rho_betta*logbetta(-1) - e_betta;
a = rho_a*a(-1)+ e_a;
y = exp(a)*k(-1)^alph*n^(1-alph);
k = (1-delt)*k(-1) + i;
alph*y/k(-1)=r;
(1-alph)*y/n = w;
phi*n^gam = w/c;
1/c = exp(logbetta)*1/c(+1)*(r(+1)+1-delt);
y = c + i;
k_m = k(-1);
logy = 100*log(y);
logc = 100*log(c);
logi = 100*log(i);
logk = 100*log(k);
logn = 100*log(n);
logw = 100*log(w);
logr = 100*log(r);
logk_m = 100*log(k_m);
end;

steady;
check;

shocks;
var e_a = sigma_a^2;
var e_betta = sigma_betta^2;
end;

stoch_simul(order = 1,irf=40) logy logc logi logk_m logn logw logr a logbetta;

// Now we simulate the response to joint shocks
//initialize IRF generation
initial_condition_states = repmat(oo_.dr.ys,1,M_.maximum_lag); % set inital value (steady-state value) for endogenous variables
shock_matrix = zeros(options_.irf,M_.exo_nbr); %create a N by M shock matrix, where N is the number of irf periods and M is the number of exogenous variables
// set combined shocks
shock_matrix(1,strmatch('e_a',M_.exo_names,'exact')) = 0.01; %set TPF shock to 1
shock_matrix(1,strmatch('e_betta',M_.exo_names,'exact')) = 0.01; %set demand shock to 1
y2 = simult_(M_,options_,initial_condition_states,oo_.dr,shock_matrix,1); %use Dynare built-in funtion "simult_" to simulate
y_IRF = y2(:,M_.maximum_lag+1:end)-repmat(oo_.dr.ys,1,options_.irf); %calculate deviation from steady state

// plot simulation results
t=linspace(1,options_.irf,options_.irf)';
index = [2,4,6,10,12,14,16,17,18];
figure
for ii = 1:9
    subplot(3,3,ii)
    id = index(ii);
    if max(abs(y_IRF(id,:)))>1e-12 %get rid of numerical inaccuracies
        %plot(y_IRF(id,:),zeros(options_.irf,1));
        plot(t,y_IRF(id,:),'-',t,zeros(options_.irf,1),'--') ;
        xlim([1 40]);
    else
        plot(zeros(options_.irf,1));
        xlim([1 40]);
    end
    title(deblank(M_.endo_names(id,:)));
end