%This code replicates Figure 11.9.1, Figure 11.9.4, Figure 11.9.5 & Figure 11.9.6 in RMT ed Ch.11
clc;clear;close all;
%Simulate using Dynare
dynare foreseen_once_for_all_increase_in_g; 
%Figure 11.9.1: foreseen_once_for_all_increase_in_g 
%Figure 11.9.4: foreseen_once_for_all_increase_in_tauc
%Figure 11.9.5: foreseen_once_for_all_increase_in_tauk 
%Figure 11.9.6: foreseen_one_time_pulse_in_g

%Inital steady state values
c0 = ys0_(1);
k0 = ys0_(2);
rbig0 = 1/beta;
eta0 = alpha*k0^(alpha-1);
g0 = 0.2;
tauc0 = 0;
tauk0 = 0;
%Path for exogenous variables
tauc = oo_.exo_simul(2:101,1);
tauk = oo_.exo_simul(2:101,2);
g = oo_.exo_simul(2:101,3);

%prices
rbig = c(2:101).^(-gamma)./(beta*c(3:102).^(-gamma)); %Note that here R_t = q_t / q_{t+1}
eta = alpha*k(1:100).^(alpha-1); %rental rate of capital

%plot
t=linspace(0,99,100)';

figure

subplot(3,3,1)
plot(t,k0*ones(100,1),'--',t,k(1:100),'-') 
title('k')
xlim([0 50])

subplot(3,3,2)
plot(t,c0*ones(100,1),'--',t,c(2:101),'-')
title('c')
xlim([0 50])

subplot(3,3,3)
plot(t,rbig0*ones(100,1),'--',t,rbig,'-') 
title('R')
xlim([0 50])

subplot(3,3,4)
plot(t,eta0*ones(100,1),'--',t,eta,'-') 
title('Eta')
xlim([0 50])

subplot(3,3,5)
plot(t,g0*ones(100,1),'--',t,g,'-') 
title('g')
xlim([0 50])
ylim([0 0.5])

subplot(3,3,6)
plot(t,tauc0*ones(100,1),'--',t,tauc,'-') 
title('tauc')
xlim([0 50])
ylim([-0.1 1])

subplot(3,3,7)
plot(t,tauk0*ones(100,1),'--',t,tauk,'-') 
title('tauk')
xlim([0 50])
ylim([-0.1 1])

